@@ -75,7 +75,7 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 
 	n_samples_ : int
 		Number of samples in the training data.
-	
+
 	X_fit_ : {array-like, sparse matrix}, shape (n_samples, n_features)
 		A reference to the training set of samples. It is used to infer which
 		UCL should be used.
@@ -394,7 +394,7 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 		t2_scores = self.score_samples(X)
 
 		return X[t2_scores <= self.ucl(X)]
-		
+
 	def cleanfit(self, X, res=1, iter=-1):
 		"""
 		Recursively remove outliers until conditions are encountered (including
@@ -405,14 +405,14 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 				- max number of iterations based on the data size
 				- smart cleaning based on normality coefficient
 					- door open for other coefs
-		
+
 		Parameters
 		----------
 		X : {array-like, sparse matrix}, shape (n_samples, n_features)
 			Training set of samples, where n_samples is the number of samples
 			and n_features is the number of features.
 
-		n : stop criteria  - minimum number of outliers (default=5)  
+		n : stop criteria  - minimum number of outliers (default=5)
 
 		TODO: add res, iter parameters.
 
@@ -426,7 +426,7 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 
 		n_iterations : number of iterations of cleaning
 
-		TODO: add Xclean2, _iter, hz values.
+		TODO: add X_clean, _iter, hz values.
 
 		Raises
 		------
@@ -434,7 +434,7 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 			If the number of samples of `X`, n_samples, is less than or equal
 			to the number of features of `X`, n_features.
 		"""
-		
+
 		# Initialization.
 		X = self._check_train_inputs(X)
 		self.n_samples_, self.n_features_ = X.shape
@@ -442,22 +442,22 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 			alpha=self.alpha)
 		self.ucl_not_indep_ = self._ucl_not_indep(self.n_samples_,
 			self.n_features_, alpha=self.alpha)
-		self.X_fit_ = X		
+		self.X_fit_ = X
 		self.cov_ = np.cov(X.T, ddof=1)
-		
+
 		# Cleanfit specific initialization.
-			
-		_res = self.n_samples_ / 2 # Variable - Initialize to the maximum		
+
+		_res = self.n_samples_ / 2 # Variable - Initialize to the maximum
 		# allowed points to be removed.
-		TOTP = self.n_samples_ # Constant - Initial number of points.
-		Xclean2 = X # Initialize second cleaned X for bootstrapping the
+		totp = self.n_samples_ # Constant - Initial number of points.
+		X_clean = X # Initialize second cleaned X for bootstrapping the
 		# iteration.
 		_iter = 0
 		hzprev = 100 # Empirically fixed based on observations on PyOD dataset -
 		# hypothesis of normality rejected if too large (generally >300).
 		_continue = 1
 		if(iter < 0):
-			hz, pval, flag = pg.multivariate_normality(Xclean2)
+			hz, pval, flag = pg.multivariate_normality(X_clean)
 			if(hz < hzprev):
 				_continue = 1
 				hzprev = hz
@@ -467,37 +467,38 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 			hz = 1
 			det = 1
 		self.set_default_ucl('not indep')
-		
+
 		# Recursivity.
-		while (_res > res) and (_iter != iter) and (Xclean2.shape[0] > TOTP/2) \
+		while (_res > res) and (_iter != iter) and (X_clean.shape[0] > totp/2) \
 			and _continue == 1:
 
-			Xclean = Xclean2
-			
-			self.fit(Xclean)
-			Xclean2 = self.transform(Xclean)
+			X_clean2 = X_clean
+			# TODO: choose a better variable name for X_clean2.
+
+			self.fit(X_clean2)
+			X_clean = self.transform(X_clean2)
 			if(iter > -1): # If iter is given, it discards criteria on HZ
 			# coefficient.
 				_continue = 1
 			else:
-				hz, pval, flag = pg.multivariate_normality(Xclean2)
-				
+				hz, pval, flag = pg.multivariate_normality(X_clean)
+
 				if(hz < hzprev):
 					_continue = 1
 					hzprev = hz
 				else:
 					_continue = 0
-					
-			_res = Xclean.shape[0] - Xclean2.shape[0]
+
+			_res = X_clean2.shape[0] - X_clean.shape[0]
 			_iter += 1
 
 		self.set_default_ucl('indep')
-		self.fit(Xclean2)
+		self.fit(X_clean)
 
 		t2_scores = self.score_samples(X)
 
-		return self, Xclean2, _iter, hz
-		
+		return self, X_clean, _iter, hz
+
 	def set_default_ucl(self, ucl):
 		"""
 		Set the default upper control limit (UCL) to either 'auto', 'indep' or
@@ -617,7 +618,7 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 
 		critical_val = stats.f.ppf(q=1-alpha, dfn=n_features,
 			dfd=n_samples-n_features)
-	
+
 		return n_features * (n_samples + 1) * (n_samples - 1) / n_samples / \
 			(n_samples - n_features) * critical_val
 
@@ -659,7 +660,7 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 
 		critical_val = stats.beta.ppf(q=1-alpha, a=n_features/2,
 			b=(n_samples-n_features-1)/2)
-	
+
 		return (n_samples - 1) ** 2 / n_samples * critical_val
 
 	def _check_inputs(self, X):
@@ -762,8 +763,7 @@ class HotellingT2(BaseEstimator, OutlierMixin, TransformerMixin):
 				" the number of features of the training set.")
 
 		return X
-			
-	
+
 if __name__ == '__main__':
 	import matplotlib.pyplot as plt
 
